@@ -34,8 +34,6 @@ def is_macos_platform():
 
 def _get_matplotib_version():
     import matplotlib
-    if is_windows_platform():
-        matplotlib.use('Qt4Agg')
     return matplotlib.__version__
 
 
@@ -60,10 +58,10 @@ def _get_slycot_version():
 
 def _get_qt_version():
     try:
-        import Qt
-        return Qt.__binding__ + ' ' + Qt.__binding_version__
+        import qtpy
+        return f'{qtpy.API_NAME} (Qt {qtpy.QT_VERSION})'
     except AttributeError as ae:
-        warnings.warn(f'importing Qt.py abstraction failed:\n{ae}')
+        warnings.warn(f'importing qtpy abstraction failed:\n{ae}')
         return False
 
 
@@ -93,7 +91,6 @@ def is_nbconvert():
 _PACKAGES = {
     'CYTHON': lambda: import_module('cython').__version__,
     'DEALII': lambda: import_module('pydealii'),
-    'DOCOPT': lambda: import_module('docopt').__version__,
     'FENICS': _get_fenics_version,
     'GL': lambda: import_module('OpenGL.GL') and import_module('OpenGL').__version__,
     'IPYTHON': _get_ipython_version,
@@ -109,12 +106,13 @@ _PACKAGES = {
     'PYTHREEJS': lambda: import_module('pythreejs._version').__version__,
     'PYEVTK': lambda: _can_import('pyevtk'),
     'QT': _get_qt_version,
-    'QTOPENGL': lambda: bool(import_module('Qt.QtOpenGL')),
+    'QTOPENGL': lambda: bool(import_module('qtpy.QtOpenGL')),
     'SCIPY': lambda: import_module('scipy').__version__,
     'SCIPY_LSMR': lambda: hasattr(import_module('scipy.sparse.linalg'), 'lsmr'),
     'SLYCOT': lambda: _get_slycot_version(),
     'SPHINX': lambda: import_module('sphinx').__version__,
     'TORCH': lambda: import_module('torch').__version__,
+    'TYPER': lambda: import_module('typer').__version__,
 }
 
 
